#define _CRT_SECURE_NO_WARNINGS

#include <iostream>
#include <cstdio>
#include <algorithm>
#include <cstdlib>
#include <cmath>
#include <vector>
#include <map>
#include <set>
#include <string>
#include <cstring>
#include <queue>
#include <ctime>
#include <cassert>
using namespace std;

const int N = 200500;

struct DSU
{
	int a[N];

	DSU()
	{
		for (int i = 0; i < N; i++)
			a[i] = i;
	}

	int get(int x)
	{
		if (a[x] == x)
			return x;
		a[x] = get(a[x]);
		return a[x];
	}

	void unite(int x, int y)
	{
		x = get(x);
		y = get(y);
		a[x] = y;
	}
};

vector<int> g[N];
DSU dsu;
int vertices;
int stack[26];

void add_edge(int a, int b)
{
	g[a].push_back(b);
	g[b].push_back(a);
}

pair<int, int> make_c()
{
	if (vertices + 2 > N)
		throw;
	int a = vertices++;
	int b = vertices++;
	add_edge(a, b);
	return make_pair(a, b);
}

struct Iterator
{
	int start, finish, link;

	Iterator() : start(-1), finish(-1), link(-1) {}

	Iterator(int _start, int _finish, int _link) :
		start(_start), finish(_finish), link(_link) {}

	int get_delta()
	{
		if (start <= finish)
			return 1;
		return -1;
	}

	void init()
	{
		if (link != -1)
			stack[link] = start;
    }

	void next()
	{
		start += get_delta();
		if (link != -1)
			stack[link] += get_delta();
	}

	bool is_bad()
	{
		return start == -1;
	}

	bool finished()
	{
		return start == finish;
	}
};

int read_value(string s)
{
	if (isdigit(s[0]))
	{
		int pos = 0;
		while (pos + 1 < (int)s.length() && isdigit(s[pos + 1]))
			pos++;
		int val = atoi(s.substr(0, pos + 1).c_str());
		return val;
	}
	if (isupper(s[0]))
	{
		int val = stack[s[0] - 'A'];
		return val;
	}
	throw;
}

Iterator get_iterator(string s)
{
	if (s == "")
		throw;
	if (isdigit(s[0]) || isupper(s[0]))
		return Iterator(1, read_value(s), -1);
	if (s[0] == 'r')
	{
		int beg = s.find('(');
		int com1 = s.find(',');
		int com2 = s.find(',', com1 + 1);
		int en = s.find(')');

		int letter = s[beg + 1] - 'A';
		int from = read_value(s.substr(com1 + 1, com2 - com1 - 1));
		int to = read_value(s.substr(com2 + 1, en - com2 - 1));
		return Iterator(from, to, letter);
	}
	return Iterator();
}

pair<int, int> perform_func(int type, pair<int, int> a, pair<int, int> b)
{
	if (type == 0 || type == 1)
	{
		dsu.unite(a.second, b.first);
		return make_pair(a.first, b.second);
	}
	dsu.unite(a.first, b.first);
	return a;
}

pair<int, int> parse(string s)
{
	if (s == "")
		throw;
	if (s == "c")
		return make_c();

	int func_type = -1;
	if (s[0] == 'c')
		func_type = 0;
	else if (s[0] == 't')
		func_type = 2;
	else if ((int)s.length() >= 4 && s.substr(0, 4) == "loop")
		func_type = 1;
	else
		throw;

	int left_bracket_pos = s.find('(');
	s = s.substr(left_bracket_pos + 1);
	s.pop_back();

	vector<int> tokens;
	tokens.push_back(-1);
	int bal = 0;
	for (int i = 0; i < (int)s.length(); i++)
	{
		if (s[i] == '(')
			bal++;
		if (s[i] == ')')
			bal--;
		if (s[i] == ',' && bal == 0)
			tokens.push_back(i);
	}
	tokens.push_back((int)s.length());

	Iterator it = get_iterator(s.substr(0, tokens[1]));
	if (it.is_bad())
	{
		pair<int, int> res(-1, -1);
		pair<int, int> the_first(-1, -1);
		for (int i = 1; i < (int)tokens.size(); i++)
		{
			pair<int, int> e = parse(s.substr(tokens[i - 1] + 1, tokens[i] - tokens[i - 1] - 1));
			if (the_first == make_pair(-1, -1))
				the_first = e;
			if (res == make_pair(-1, -1))
				res = e;
			else
		    	res = perform_func(func_type, res, e);
		}
		if (func_type == 1)
		{
			perform_func(0, res, the_first);
			return the_first;
		}
		return res;
	}

	it.init();
	pair<int, int> res(-1, -1);
	pair<int, int> the_first(-1, -1);
	while (true)
	{
		pair<int, int> e;
		if ((int)tokens.size() == 2)
			e = make_c();
		else
			e = parse(s.substr(tokens[1] + 1, tokens[2] - tokens[1] - 1));
		if (the_first == make_pair(-1, -1))
			the_first = e;
		if (res == make_pair(-1, -1))
			res = e;
		else
			res = perform_func(func_type, res, e);
		if (it.finished())
			break;
		it.next();
	}
	if (func_type == 1)
	{
		perform_func(0, res, the_first);
		return the_first;
	}
	return res;
}

struct Edge
{
	int from, to, flag;

	Edge() : from(), to(), flag() {}

	Edge(int _from, int _to, int _flag) : from(_from), to(_to), flag(_flag) {}
};

vector<int> graph[N];
vector<Edge> edges;
vector<Edge> ans;
bool used[N];

void dfs(int v)
{
	for (int ind : graph[v])
	{
		int to = edges[ind].to;
		if (v == to)
			to = edges[ind].from;

		if (used[ind])
			continue;
		used[ind] = true;
		dfs(to);

		ans.push_back(Edge(v, to, edges[ind].flag));
	}
}

void solve()
{
	string s;
	cin >> s;
	pair<int, int> fs = parse(s);
	fs.first = dsu.get(fs.first);
	fs.second = dsu.get(fs.second);

	for (int i = 0; i < vertices; i++)
	{
		int root = dsu.get(i);
		if (root != i)
		{
			for (int e : g[i])
				g[root].push_back(dsu.get(e));
		}
		else
		{
			for (int & e : g[i])
				e = dsu.get(e);
		}
	}

	map<int, int> dict;
	dict[fs.first] = 0;
	for (int i = 0; i < vertices; i++)
	{
		if (dsu.get(i) != i)
			continue;
		for (int e : g[i])
		{
			if (e != fs.second && dict.count(e) == 0)
			{
				int size = (int)dict.size();
				dict[e] = size;
			}
		}
	}
	dict[fs.second] = (int)dict.size();

	for (int i = 0; i < vertices; i++)
	{
		if (dsu.get(i) != i)
			continue;
		sort(g[i].begin(), g[i].end());
		g[i].resize(unique(g[i].begin(), g[i].end()) - g[i].begin());
	}

	for (int i = 0; i < vertices; i++)
	{
		if (dsu.get(i) != i)
			continue;
		int v1 = dict[i];
		for (int e : g[i])
		{
			int v2 = dict[e];
			if (v1 < v2)
			{
				edges.push_back(Edge(v1, v2, true));
				graph[v1].push_back((int)edges.size() - 1);
				graph[v2].push_back((int)edges.size() - 1);
			}
		}
	}

	int n = (int)dict.size();
	vector<int> odd;
	for (int i = 0; i < n; i++)
	{
		if (graph[i].size() % 2 == 1)
			odd.push_back(i);
	}

	while (!odd.empty())
	{
		int v1 = odd.back();
		odd.pop_back();
		int v2 = odd.back();
		odd.pop_back();
		edges.push_back(Edge(v1, v2, false));
		graph[v1].push_back((int)edges.size() - 1);
		graph[v2].push_back((int)edges.size() - 1);
	}

	dfs(0);

	reverse(ans.begin(), ans.end());
	vector<vector<int>> path;
	vector<int> cur_path;
	int start_v = 0;
	for (int i = 0; i < (int)ans.size(); i++)
	{
		if (!ans[i].flag)
		{
			start_v = (i + 1) % ans.size();
			break;
		}
	}

	cur_path.push_back(ans[start_v].from);
	for (int i = 0; i < (int)ans.size(); i++)
	{
		if (!ans[i].flag)
		{
			if (cur_path.size() > 1)
			    path.push_back(cur_path);
			cur_path.clear();
			cur_path.push_back(ans[i].from);
			continue;
		}
		cur_path.push_back(ans[start_v].to);

		start_v = (start_v + 1) % (int)ans.size();
	}
	if (cur_path.size() > 1)
		path.push_back(cur_path);

	printf("%d %d\n", n, (int)path.size());
	for (int i = 0; i < (int)path.size(); i++)
	{
		printf("%d ", (int)path[i].size());
		for (int j = 0; j < path[i].size(); j++)
			printf("%d ", path[i][j] + 1);
		printf("\n");
	}
}

int main()
{
	freopen("cactus.in", "r", stdin);
	freopen("cactus.out", "w", stdout);

	solve();

	return 0;
}