#define _CRT_SECURE_NO_WARNINGS

#include <iostream>
#include <cstdio>
#include <algorithm>
#include <cstdlib>
#include <cmath>
#include <vector>
#include <map>
#include <set>
#include <string>
#include <cstring>
#include <queue>
#include <ctime>
#include <cassert>
using namespace std;

#pragma comment(linker, "/STACK:64000000")

const int N = (int)(1 << 18);
const int INF = (int)1e9;

struct IntervalTree
{
	int cnt[2 * N];
	int min_val[2 * N];

	IntervalTree()
	{
		for (int i = 0; i < 2 * N; i++)
		{
			cnt[i] = 0;
			min_val[i] = INF;
		}
	}

	void set(int pos, int ncnt, int nval)
	{
		pos += N;
		cnt[pos] = ncnt;
		min_val[pos] = nval;
		pos /= 2;
		while (pos >= 1)
		{
			cnt[pos] = cnt[pos * 2] + cnt[pos * 2 + 1];
			min_val[pos] = min(min_val[pos * 2], min_val[pos * 2 + 1]);
			pos /= 2;
		}
	}

	int get_min(int a, int b)
	{
		if (a > b)
			return INF;
		return get_min(1, 0, N - 1, a, b);
	}

	int get_min(int v, int l, int r, int a, int b)
	{
		if (l > b || r < a)
			return INF;
		if (a <= l && r <= b)
			return min_val[v];
		int m = (l + r) / 2;
		return min(get_min(v * 2, l, m, a, b), get_min(v * 2 + 1, m + 1, r, a, b));
	}

	int get_cnt(int a, int b)
	{
		if (a > b)
			return 0;
		return get_cnt(1, 0, N - 1, a, b);
	}

	int get_cnt(int v, int l, int r, int a, int b)
	{
		if (l > b || r < a)
			return 0;
		if (a <= l && r <= b)
			return cnt[v];
		int m = (l + r) / 2;
		return get_cnt(v * 2, l, m, a, b) + get_cnt(v * 2 + 1, m + 1, r, a, b);
	}
};

int n;
int perm[N];
int ind_to_pos[N];
IntervalTree tree;

void scan()
{
	scanf("%d", &n);
	for (int i = 1; i <= n; i++)
	{
		scanf("%d", &perm[i]);
		perm[i];
	}
	n++;
	perm[0] = 0;
}

int rec(int l, int r)
{
	if (l >= r)
		return 0;

	int min_el = tree.get_min(l, r);
	if (min_el == INF)
		return 0;

	int pos = ind_to_pos[min_el];

	tree.set(pos, 0, INF);

	int ans = rec(l, r) + 1;

	int lans = rec(l, pos - 1) + tree.get_cnt(pos + 1, r);
	int rans = rec(pos + 1, r) + tree.get_cnt(l, pos - 1);

	ans = min(ans, lans);
	ans = min(ans, rans);

	tree.set(pos, 1, min_el);
    
	return ans;
}

int solve()
{
	for (int i = 0; i < n; i++)
		ind_to_pos[i] = perm[i];

	for (int i = 0; i < n; i++)
		tree.set(ind_to_pos[i], 1, i);

	return n - 1 - rec(0, n - 1);
}

int main()
{
	freopen("improvements.in", "r", stdin);
	freopen("improvements.out", "w", stdout);

	scan();
	int ans = solve();
	printf("%d", ans);

	return 0;
}