#include <stdio.h>
#include <iostream>
#include <string.h>
#include <stdlib.h>
#include <math.h>
#include <ctype.h>
#include <iostream>
#include <vector>
#include <string>
#include <map>
#include <set>
#include <queue>
#include <algorithm>
using namespace std;

typedef long long LL;
typedef long long ll;
typedef pair<int, int> pii;

const int INF = 1000000000;
const LL LINF = 1000000000000000000LL;
#define FOR(i,a,b) for(int i=(a);i<(b);i++)
#define ROF(i,a,b) for(int i=(b)-1;i>=(a);i--)

#ifdef LOCAL
#include <windows.h>
#endif

#define PROBLEM "damage"

const double PI = 3.1415926535897932384626433832795;
const double EPS = 1e-8;

const int PARTS = 1500000;

double semic(double r, double x) {
  double phi = acos(1 - (x / r));
  return (phi - sin(2 * phi) / 2) * r * r;
}
double semich(double r, double x) {
  double phi = acos(max(min(1 - (x / r), 1.0), -1.0));
  double s0 = (phi - sin(2 * phi) / 2) * r * r;
  double s1 = sin(phi);
  s1 = 2 * s1 * s1 * s1 / 3 * r * r;
  return (s1 - s0 * cos(phi)) * r;
}

double vcone(double r, double x, double h) {
  double ret = 0;
  FOR(i, 0, PARTS) {
    double H = h * (i + 0.5) / PARTS;
    double dh = h / PARTS;
    ret += dh * semic(r, x * H / h);
  }
  return ret;
}

double vcap(double R, double H, double t, double phi) {
  double ret = 0;
  FOR(i, 0, PARTS) {
    double dalpha = phi / PARTS;
    double alpha = phi * (i + 0.5) / PARTS;

    double sa = sin(alpha);
    double ca = cos(alpha);
    double tau = -t * sa + H * ca;
    double _x = -tau * sa;
    double _y = tau * ca;
    double r = sqrt(R * R - tau * tau);
    double x = r - ((t - _x) * ca + (H - _y) * sa);

    ret += dalpha * semich(r, x);
  }
  return ret;
}

double solve(double d, double l, double r, double t, double h, bool flip = false) {
  double slant = asin(max(min(t / l, 1.0), 0.0));
  double H = sqrt(max(r * r - (d / 2) * (d / 2), 0.0));
  double h0 = d * cos(slant);
  double d2 = d / 2;
  double volume = PI * (r * r * (r - H) - r * r * r / 3 + H * H * H / 3);
  if (h > h0 - EPS && h < t - EPS) {
    double h1 = l * h / t;
    double h2 = l * (h - h0) / t;
    return (h1 + h2) / 2 * d2 * d2 * PI + volume;
  }

  double inner = 0;
  if (h < h0 - EPS && h < t - EPS) {
    inner = vcone(d2, h / h0 * d, l * h / t);
  } else if (h > h0 + EPS && h > t + EPS) {
    inner = l * d2 * d2 * PI - vcone(d2, d * (t + h0 - h) / h0, (t + h0 - h) * l / t);
  } else if (t > EPS) {
    double l0 = h * l / t;
    inner = vcone(d2, h / h0 * d, l0) - vcone(d2, (h - t) / h0 * d, l0 - l);
  } else {
    inner = l * semic(d2, h);
  }

  if (h > t + EPS) {
    inner += vcap(r, H, d2 - (h - t) / h0 * d, PI / 2 - slant);
  }
  if (h < h0 - EPS) {
    inner += volume - vcap(r, H, h / h0 * d - d2, PI / 2 - slant);
  } else {
    inner += volume;
  }

//  return volume * 2 + d2 * d2 * PI * l;

  return inner;
}

int main() {
#ifdef LOCAL
  freopen("input.txt", "rt", stdin);
  freopen("output.txt", "wt", stdout);
  int _tt = GetTickCount();
#else
  freopen(PROBLEM ".in", "rt", stdin);
  freopen(PROBLEM ".out", "wt", stdout);
#endif

  double d, l, r, t, h;
  cin >> d >> l >> r >> t >> h;
  cout.precision(5);
  cout << fixed << solve(d * 0.001, l * 0.001, r * 0.001, t * 0.001, h * 0.001) * 1000;

#ifdef LOCAL
  cerr << double(GetTickCount() - _tt) * 0.001 << endl;
#endif
  return 0;
}

