#include <cstdio>
#include <map>
#include <iostream>
#include <cstring>
#include <cassert>
#include <algorithm>

using namespace std;

const int N = 800010;

int dsu[N];

int find_set(int x) {
  if (x != dsu[x]) {
    dsu[x] = find_set(dsu[x]);
  }
  return dsu[x];
}

void unite(int x, int y) {
  x = find_set(x);
  y = find_set(y);
  if (x == y) {
    return;
  }
  dsu[x] = y;
}

typedef pair <int, int> Graph;

vector < pair <int, int> > edges;
char s[N];
int peek;
int cnt;

Graph make_c() {
  Graph ret = make_pair(cnt, cnt + 1);
  edges.push_back(make_pair(cnt, cnt + 1));
  cnt += 2;
  return ret;
}

Graph parse_graph(map <char, int> values);

vector <Graph> parse_list(map <char, int> values) {
  if (s[peek] == 'c' || s[peek] == 'l' || s[peek] == 't') {
    vector <Graph> ret;
    while (s[peek] == 'c' || s[peek] == 'l' || s[peek] == 't') {
      ret.push_back(parse_graph(values));
      assert(s[peek] == ',' || s[peek] == ')');
      peek++;
    }
    return ret;
  }
  if (('0' <= s[peek] && s[peek] <= '9') || ('A' <= s[peek] && s[peek] <= 'Z')) {
    int num = 0;
    if ('0' <= s[peek] && s[peek] <= '9') {
      while ('0' <= s[peek] && s[peek] <= '9') {
        num = num * 10 + s[peek] - '0';
        peek++;
      }
    } else {
      num = values[s[peek]];
      peek++;
    }
    if (s[peek] == ')') {
      vector <Graph> ret;
      for (int j = 0; j < num; j++) {
        ret.push_back(make_c());
      }
      peek++;
      return ret;
    }
    assert(s[peek] == ',');
    peek++;
    vector <Graph> ret;
    int pos = peek;
    for (int j = 0; j < num; j++) {
      peek = pos;
      ret.push_back(parse_graph(values));
    }
    assert(s[peek] == ')');
    peek++;
    return ret;
  }
  assert(s[peek] == 'r');
  while (s[peek] != '(') {
    peek++;
  }
  peek++;
  char var = s[peek];
  assert('A' <= var && var <= 'Z');
  peek++;
  peek++;
  int A = 0;
  int B = 0;
  if ('0' <= s[peek] && s[peek] <= '9') {
    while ('0' <= s[peek] && s[peek] <= '9') {
      A = A * 10 + s[peek] - '0';
      peek++;
    }
  } else {
    assert('A' <= s[peek] && s[peek] <= 'Z');
    A = values[s[peek]];
    peek++;
  }
  peek++;
  if ('0' <= s[peek] && s[peek] <= '9') {
    while ('0' <= s[peek] && s[peek] <= '9') {
      B = B * 10 + s[peek] - '0';
      peek++;
    }
  } else {
    assert('A' <= s[peek] && s[peek] <= 'Z');
    B = values[s[peek]];
    peek++;
  }
  peek++;
  if (s[peek] == ')') {
    vector <Graph> ret;
    int pos = peek;
    for (int x = min(A, B); x <= max(A, B); x++) {
      ret.push_back(make_c());
    }
    peek++;
    return ret;
  }
  assert(s[peek] == ',');
  peek++;
  vector <Graph> ret;
  int pos = peek;
  for (int x = min(A, B); x <= max(A, B); x++) {
    map <char, int> new_values = values;
    new_values[var] = x;
    peek = pos;
    ret.push_back(parse_graph(new_values));
  }
  assert(s[peek] == ')');
  peek++;
  return ret;
}

Graph parse_graph(map <char, int> values) {
  char c = s[peek];
  peek++;
  if (c == 'c') {
    if (s[peek] != '(') {
      return make_c();
    }
  }
  while (s[peek] != '(') {
    peek++;
  }
  peek++;
  vector <Graph> glist = parse_list(values);
  int gsz = glist.size();
  if (c == 'c') {
    for (int i = 0; i < gsz - 1; i++) {
      unite(glist[i].second, glist[i + 1].first);
    }
    return make_pair(glist[0].first, glist[gsz - 1].second);
  }
  if (c == 'l') {
    for (int i = 0; i < gsz; i++) {
      unite(glist[i].second, glist[(i + 1) % gsz].first);
    }
    return make_pair(glist[0].first, glist[0].second);
  }
  if (c == 't') {
    for (int i = 1; i < gsz; i++) {
      unite(glist[i].first, glist[0].first);
    }
    return make_pair(glist[0].first, glist[0].second);
  }
  assert(false);
}

int deg[N], id[N];

vector < pair <int, int> > g[N];
vector <int> path;
int ptr[N];
bool used[N];

void dfs(int v) {
  while (ptr[v] < g[v].size()) {
    int to = g[v][ptr[v]].first;
    int id = g[v][ptr[v]].second;
    ptr[v]++;
    if (!used[id]) {
      used[id] = true;
      dfs(to);
      path.push_back(id);
    }
  }
}

int main() {
  freopen("cactus.in", "r", stdin);
  freopen("cactus.out", "w", stdout);
  scanf("%s", s);
  for (int i = 0; i < N; i++) {
    dsu[i] = i;
  }
  cnt = 0;
  peek = 0;
  edges.clear();
  Graph res = parse_graph(map <char, int>());
  res.first = find_set(res.first);
  res.second = find_set(res.second);
  for (int i = 0; i < cnt; i++) {
    deg[i] = 0;
  }
  for (int i = 0; i < (int)edges.size(); i++) {
    edges[i].first = find_set(edges[i].first);
    edges[i].second = find_set(edges[i].second);
    deg[edges[i].first]++;
    deg[edges[i].second]++;
  }
  int n = 0;
  for (int i = 0; i < cnt; i++) {
    id[i] = -1;
    if (deg[i] > 0) {
      n++;
    }
  }
  id[res.first] = 1;
  id[res.second] = n;
  int cur_id = 2;
  for (int i = 0; i < cnt; i++) {
    if (deg[i] > 0 && id[i] == -1) {
      id[i] = cur_id++;
    }
  }
  for (int i = 0; i < (int)edges.size(); i++) {
    edges[i].first = id[edges[i].first];
    edges[i].second = id[edges[i].second];
  }
  vector <int> odd;
  for (int i = 0; i < cnt; i++) {
    if (deg[i] & 1) { 
      odd.push_back(id[i]);
    }
  }
  int real = edges.size();
  for (int i = 0; i < (int)odd.size(); i += 2) {
    edges.push_back(make_pair(odd[i], odd[i + 1]));
  }
  for (int i = 1; i <= n; i++) {
    g[i].clear();
  }
  for (int i = 0; i < (int)edges.size(); i++) {
    g[edges[i].first].push_back(make_pair(edges[i].second, i));
    g[edges[i].second].push_back(make_pair(edges[i].first, i));
//    cerr << i << " -> " << edges[i].first << " " << edges[i].second << endl;
    used[i] = false;
  }
  for (int i = 1; i <= n; i++) {
    ptr[i] = 0;
  }
  path.clear();
  dfs(1);
  vector < vector <int> > paths;
  int ps = path.size();
  for (int i = 0; i < ps; i++) {
    if (path[i] >= real) {
      int u = (i + 1) % ps;
      while (true) {
        paths.push_back(vector <int>());
        while (path[u] < real) {
          paths[paths.size() - 1].push_back(path[u]);
          u = (u + 1) % ps;
        }
        if (u == i) {
          break;
        }
        u = (u + 1) % ps;
      }
      break;
    }
  }
  if (paths.size() == 0) {
    paths.push_back(vector <int>());
    for (int i = 0; i < ps; i++) {
      paths[paths.size() - 1].push_back(path[i]);
    }
  }
  printf("%d %d\n", n, (int)paths.size());
  for (int i = 0; i < (int)paths.size(); i++) {
    int cur = paths[i].size();
    if (cur == 1) {
      printf("2 %d %d\n", edges[paths[i][0]].first, edges[paths[i][0]].second);
      continue;
    }
    int start = edges[paths[i][0]].first;
    if (start == edges[paths[i][1]].first || start == edges[paths[i][1]].second) {
      start = edges[paths[i][0]].second;
    }
    printf("%d %d", (int)paths[i].size() + 1, start);
    for (int j = 0; j < (int)paths[i].size(); j++) {
      start = start ^ edges[paths[i][j]].first ^ edges[paths[i][j]].second;
      printf(" %d", start);
    }
    printf("\n");
  }
  return 0;
}
