import java.io.*;
import java.util.StringTokenizer;

/**
 * Created by neerc on 07.12.2014.
 */
public class F {

    private BufferedReader in;
    private PrintWriter out;
    private StringTokenizer st;

    public static void main(String[] args) throws IOException {
        final F solver = new F();
        solver.open();
        solver.solve();
        solver.close();
    }

    private String nextToken() throws IOException {
        while (st == null || !st.hasMoreElements()) {
            st = new StringTokenizer(in.readLine());
        }
        return st.nextToken();
    }

    private int nextInt() throws IOException {
        return Integer.parseInt(nextToken());
    }

    private long nextLong() throws IOException {
        return Long.parseLong(nextToken());
    }

    private double nextDouble() throws IOException {
        return Double.parseDouble(nextToken());
    }

    private final String filename = "filter";

    private int BITS_IN_FILTER;
    private final int BITS_IN_SEGMENT = 50;

    private long[] getMaskPlaceholder() {
        return new long[BITS_IN_FILTER / BITS_IN_SEGMENT + (BITS_IN_FILTER % BITS_IN_SEGMENT == 0 ? 0 : 1)];
    }

    private void setBit(final long[] mask, final long bitNumber) {
        mask[(int) (bitNumber / BITS_IN_SEGMENT)] |= 1 << (bitNumber % BITS_IN_SEGMENT);
    }
//
//    private boolean getBit(final long[] mask, final long bitNumber) {
//        final int bitForCheck = 1 << (bitNumber % BITS_IN_SEGMENT);
//        return (mask[(int) (bitNumber / BITS_IN_SEGMENT)] & bitForCheck) == bitForCheck;
//    }

    private long[] getMask(final int userId, final long[] hashes) {
        final long[] mask = getMaskPlaceholder();
        for (final long hash : hashes) {
            setBit(mask, (userId * hash) % BITS_IN_FILTER);
        }
        return mask;
    }

    private boolean contains(final long[] filter, final long[] mask) {
        final int n = filter.length;
        for (int i = 0; i < n; i++) {
            if ((filter[i] & mask[i]) != mask[i])
                return false;
        }
        return true;
    }

    private long[] parseFilter(final String mask) {
        int bitNumber = 0;
        final long[] result = getMaskPlaceholder();
        for (final char c : mask.toCharArray()) {
            int bits = Character.isDigit(c) ? c - '0' : c - 'a' + 10;
            for (int i = 0; i < 4; i++) {
                if (bitNumber < BITS_IN_FILTER && ((bits >> i) & 1) == 1) {
                    setBit(result, bitNumber);
                }
                bitNumber++;
            }
        }
        return result;
    }

    public void solve() throws IOException {
        BITS_IN_FILTER = nextInt();
        final int f = nextInt();
        final long[] hash = new long[f];
        for (int i = 0; i < f; i++) {
            hash[i] = nextLong();
        }

        final int filtersNumber = nextInt();
        final long[][] filters = new long[filtersNumber][];
        for (int i = 0; i < filtersNumber; i++) {
            filters[i] = parseFilter(nextToken());
        }

        final boolean[] answer = new boolean[filtersNumber];

        final int querysNumber = nextInt();
        for (int i = 0; i < querysNumber; i++) {
            final int userId = nextInt();
            final long[] mask = getMask(userId, hash);
            for (int j = 0; j < filtersNumber; j++) {
                if (!answer[j]) { //We optimize here - do not check filter that already will be in result
                    answer[j] = contains(filters[j], mask);
                }
            }
        }

        int result = 0;
        for (int i = 0; i < filtersNumber; i++) {
            if (answer[i])
                result++;
        }
        out.print(result);
        out.print(' ');
        for (int i = 0; i < filtersNumber; i++) {
            if (answer[i]) {
                out.print(i);
                out.print(' ');
            }
        }
        out.println();
    }

    public void open() throws IOException {
        in = new BufferedReader(new FileReader(filename + ".in"));
        out = new PrintWriter(new FileWriter(filename + ".out"));

//        out = new PrintWriter(System.out);
    }

    public void close() {
        out.flush();
        out.close();
    }

}
