
import java.util.*;
import java.io.*;

import static java.lang.Math.*;

public class E {

	final boolean ONLINE_JUDGE = !new File("input.txt").exists();
	
	BufferedReader in;
	PrintWriter out;
	StringTokenizer tok = new StringTokenizer("");
	
	public static void main(String[] args) {
		new E().run();
	}
	
	public void run() {
		try {
			long t1 = System.currentTimeMillis();
			
			init();
			solve();
			
			out.close();
			
			long t2 = System.currentTimeMillis();
			System.err.println(t2 - t1);
		} catch (Exception e) {
			e.printStackTrace();
			System.exit(-1);
		}
	}
	
	public void init() throws IOException {
		String fileName = "epic";
		if (fileName.isEmpty()) {
			throw new RuntimeException();
		}
		
		if (ONLINE_JUDGE) {
			in = new BufferedReader(new FileReader(fileName + ".in"));
			out = new PrintWriter(fileName + ".out");
		} else {
			in = new BufferedReader(new FileReader("input.txt"));
			out = new PrintWriter("output.txt");
		}
	}
	
	public String readString() throws IOException {
		while (!tok.hasMoreTokens()) {
			tok = new StringTokenizer(in.readLine());
		}
		
		return tok.nextToken();
	}
	
	int readInt() throws IOException {
		return Integer.parseInt(readString());
	}
	
	long readLong() throws IOException {
		return Long.parseLong(readString());
	}
	
	String typeStrings = "RPS";
	
	int[] types;
	int[][] graph;
	
	
	int INDEX = 0;
	class Vertex {
		int index;
		BitSet can;
		
		int count;
		int type;
		
		Vertex[] edges;
		public Vertex(int index, int type, int count, BitSet can) {
			super();
			this.index = index;
			this.type = type;
			
			this.can = can;
			this.count = count;
			
			this.edges = new Vertex[3];
		}
		
	}
	
	int n;
	Map<BitSet, Vertex> map;
	
	Vertex[] vertexes;
	
	void solve() throws IOException {
		 n = readInt();
		 
		 types = new int[n];
		 graph = new int[3][n];
		 
		 for (int i = 0; i < n; ++i) {
			 types[i] = typeStrings.indexOf(readString());
			 
			 for (int j = 0; j < 3; ++j) {
				 graph[j][i] = readInt() - 1;
			 }
		 }
		 
		 map = new HashMap<BitSet, Vertex>();
		 
		 BitSet startCan = new BitSet(n);
		 startCan.set(0, n);
		 
		 winVertexes = new Vertex[n];
		 
		 Vertex start = (n == 1 ? getWinVertex(0) : getBestVertex(startCan));
		 
		 used = new HashSet<Integer>();
		 dfs(start);
		 
		 int size = INDEX;
		 vertexes = new Vertex[size];
		 
		 create(start);
		 
		 out.println(size);
		 for (Vertex v : vertexes) {
			 out.println(typeStrings.charAt(v.type) + " " + (v.edges[0].index + 1) + " " + (v.edges[1].index + 1) + " " + (v.edges[2].index + 1));
		 }
	}
	
	void create(Vertex from) {
		used.remove(from.index);
		vertexes[from.index] = from;
		
		for (int op = 0; op < 3; ++op) {
			if (used.contains(from.edges[op].index)) {
				create(from.edges[op]);
			}
		}
	}
	
	Vertex add(Map<BitSet, Vertex> map, Vertex v) {
		Vertex vv = map.get(v.can);
		if (vv != null) return vv;
		else {
			map.put(v.can, v);
			return v;
		}
		
	}
	
	Set<Integer> used;
	
	void dfs(Vertex from) {
		used.add(from.index);
		BitSet fromCan = from.can;
		
		if (from.count == 1) {
			return;
		}
		
		for (int op = 0; op < 3; ++op) {
			BitSet toCan = new BitSet(n);
			for (int i = 0; i < n; ++i) {
				if (types[i] == op && fromCan.get(i)) {
					toCan.set(graph[from.type][i]);
				}
			}
			
			if (toCan.cardinality() == 1) {
				from.edges[op] = getWinVertex(toCan.nextSetBit(0));
			} else {
				from.edges[op] = getBestVertex(toCan);
			}
			
			
		}
		
		for (int op = 0; op < 3; ++op) {
			if (!used.contains(from.edges[op].index)) {
				dfs(from.edges[op]);
			}
		}
	}
	
	Vertex[] winVertexes;
	
	Vertex getWinVertex(int cur) {
		if (winVertexes[cur] != null) return winVertexes[cur];
		
		int ourType = (types[cur] + 1) % 3;
		Vertex our = new Vertex(INDEX++, ourType, 1, null);
		
		used.add(our.index);
		
		winVertexes[cur] = our;
		our.edges[0] = our.edges[1] = our.edges[2] = getWinVertex(graph[ourType][cur]);
		
		return our;
	}
	
	Vertex getBestVertex(BitSet toCan) {
		int best = -1;
		int bestCount = n + 1;
		
		for (int fromNextType = 0; fromNextType < 3; ++fromNextType) {
			
			int maxCount = -1; 
			for (int opNext = 0; opNext < 3; ++opNext) {
				BitSet toNextCan = new BitSet(n);
				for (int i = 0; i < n; ++i) {
					if (types[i] == opNext && toCan.get(i)) {
						toNextCan.set(graph[fromNextType][i]);
					}
				}
				
				maxCount = max(maxCount, toNextCan.cardinality());
			}
			
			if (maxCount < bestCount) {
				best = fromNextType;
				bestCount = maxCount;
			}
		}
		
		return	map.containsKey(toCan) 
				? map.get(toCan) 
				: add(map, new Vertex(INDEX++, best, toCan.cardinality(), toCan));
	}
}
