// Main.cpp : Defines the entry point for the console application.
//

#include <iostream>
#include <fstream>
#include <cstddef>
#include <vector>
#include <algorithm>
#include <string>
#include <numeric>
#include <utility>
#include <unordered_map>
#include <iomanip>
#include <bitset>

#ifdef _DEBUG

auto& in = std::cin;
auto& out = std::cout;

#else

std::ifstream in("filter.in");
std::ofstream out("filter.out");

#endif

std::unordered_map<char, unsigned char> CHAR_TO_BITS
{
	{ '0', 0 },
	{ '1', 1 },
	{ '2', 2 },
	{ '3', 3 },
	{ '4', 4 },
	{ '5', 5 },
	{ '6', 6 },
	{ '7', 7 },
	{ '8', 8 },
	{ '9', 9 },
	{ 'a', 10 },
	{ 'b', 11 },
	{ 'c', 12 },
	{ 'd', 13 },
	{ 'e', 14 },
	{ 'f', 15 },
};

std::vector<unsigned char> to_bits(const std::string& str)
{
	std::vector<unsigned char> ans;

	for (const auto& x : str)
	{
		ans.push_back(CHAR_TO_BITS.at(x));
	}

	return ans;
}

bool check_bit(const std::vector<unsigned char>& file, unsigned long long a, unsigned long long u, std::size_t m)
{
	auto j = (u * a) % m;
	auto part = file.at(j / 4);
	return part & (1 << (j % 4));
}

bool check_bits(const std::vector<unsigned char>& file, const std::vector<unsigned long long>& ax, unsigned long long u, std::size_t m)
{
	return std::all_of(std::begin(ax), std::end(ax), [&file, u, m](unsigned long long a){
		return check_bit(file, a, u, m);
	});
}

bool check_file(const std::vector<unsigned long long>& ax, const std::vector<unsigned char>& file, const std::vector<unsigned long long>& users, std::size_t m)
{
	return std::any_of(std::begin(users), std::end(users), [&file, &ax, m](unsigned long long u){
		return check_bits(file, ax, u, m);
	});
}

int main()
{
	std::size_t m, f;
	in >> m >> f;

	std::vector<unsigned long long> a(f);
	for (auto& x : a)
	{
		in >> x;
	}

	std::size_t n;
	in >> n;

	std::vector<std::vector<unsigned char>> files(n);

	for (auto& file : files)
	{
		std::string str;
		in >> str;
		file = to_bits(str);
	}

	std::size_t q;
	in >> q;

	std::vector<unsigned long long> users(q);
	for (auto& user : users)
	{
		in >> user;
	}

	std::vector<std::size_t> ans;
	for (std::size_t i = 0; i < files.size(); ++i)
	{
		if (check_file(a, files.at(i), users, m))
		{
			ans.push_back(i);
		}
	}
	
	out << ans.size() << ' ';
	for (const auto& x : ans)
	{
		out << x << ' ';
	}

	out << std::endl;
}
