#define _CRT_SECURE_NO_WARNINGS

#include <iostream>

using namespace std;

const int ITER = 20000000;
const double PI = acos(-1.0);

double randInRange(double a, double b){
	return ((rand() + 0.0) / RAND_MAX) * (b - a) + a;
}

bool doubleEqual(double a, double b){
	return fabs(a - b) < 1e-8;
}

bool doubleLessOrEqual(double a, double b){
	return doubleEqual(a, b) || a < b;
}

bool doubleGreaterOrEqual(double a, double b){
	return doubleEqual(a, b) || a > b;
}

struct vec{
	double x, y, z;

	vec(){
		x = y = z = 0.0;
	}
	vec(double _x, double _y, double _z){
		x = _x;
		y = _y;
		z = _z;
	}

	double operator % (const vec &other) const{
		return x * other.x + y * other.y + z * other.z;
	}

	vec operator * (const vec &other) const{
		return vec(y * other.z - z * other.y,
			z * other.x - x * other.z,
            x * other.y - y * other.x
			);
	}

	double length() const{
		return sqrt(*this % *this);
	}

	vec operator / (const double a) const{
		return vec(x / a, y / a, z / a);
	}
	vec operator * (const double a) const{
		return vec(x * a, y * a, z * a);
	}

	vec resize(double l = 1.0) const{
		return *this / length() * l;
	}

	vec operator + (const vec &other) const{
		return vec(x + other.x, y + other.y, z + other.z);
	}
	vec operator - (const vec &other) const{
		return vec(x - other.x, y - other.y, z - other.z);
	}

	double distTo(vec &other) const{
		return (*this - other).length();
	}

	double distTo(vec &A, vec &B) const{
		vec C = *this;
		vec AB = B - A;
		vec AC = C - A;

		return (AB * AC).length() / AB.length();
	}
};

double d, l, r, t, h;
vec O1, O2, C1, C2;
double k;

bool pointInEben(const vec &A){

	if (!doubleEqual((C1 - C2).length(), l))
		throw;

	bool inSegment = doubleGreaterOrEqual((A - C1) % (C2 - C1), 0.0) &&
		doubleGreaterOrEqual((A - C2) % (C1 - C2), 0.0);
	if (doubleLessOrEqual(A.distTo(O1, O2), d / 2.0) && inSegment)
		return true;

	return (doubleLessOrEqual(A.distTo(O1), r) ||
		doubleLessOrEqual(A.distTo(O2), r)) &&
		doubleLessOrEqual(A.distTo(O1, O2), d / 2.0);
}

int main(){
	freopen("damage.in", "rt", stdin);
	freopen("damage.out", "wt", stdout);

	scanf("%lf%lf%lf%lf%lf", &d, &l, &r, &t, &h);
	d /= 100.0;
	l /= 100.0;
	r /= 100.0;
	t /= 100.0;
	h /= 100.0;

	O1 = vec(0, 0, r);
	vec O1O2 = vec(0, sqrt(l*l - t*t), t);
	k = sqrt(r*r - (d / 2.0)*(d / 2.0));
	O2 = O1O2.resize(l - 2.0*k) + O1;

	C1 = (O1 - O2).resize(k) + O1;
	C2 = (O2 - O1).resize(k) + O2;


	vec per = vec(0, t, -sqrt(l*l - t*t));
	vec low = C1 + per.resize(d / 2.0);

	int sum1 = 0;
	int sum2 = 0;

	vec D1 = O1 - O1O2.resize(r);
	vec D2 = O2 + O1O2.resize(r);

	for (int i = 0; i < ITER; ++i){
		vec P = (D2 - D1).resize(randInRange(0, 1.0) * (D1 - D2).length()) + D1;
		P = P + per.resize(randInRange(-d/2.0, d/2.0));
		P = P + vec(1, 0, 0).resize(randInRange(-d/2.0, d/2.0));
		//vec A = vec(randInRange(-r, r), randInRange(-r, l + 2.0*r), randInRange(-r, l + 2.0*r));
		vec A = P;

		if (pointInEben(A)){
			++sum1;
			if (doubleLessOrEqual(A.z, h+low.z)){
				++sum2;
			}
			//else
			//{
			//	printf("ololo");
			//}
		}
	}

	double alpha = asin(d / r / 2.0) * 2.0;


	double V = 0;
	double sectors = 2.0 * r * r * r * 2.0 / 3.0 * (1.0 - sin((PI - alpha) / 2.0)) * PI;
	double conuses = 2.0 * PI * (d / 2.0) * (d / 2.0) * k / 3.0;
	double cilindre = PI * (d / 2.0) * (d / 2.0) * l;
	V = sectors + cilindre - conuses;
	double ans = V / sum1 * sum2;

	printf("%.2lf\n", ans);   
}