#include <iostream>
#include <queue>
#include <vector>
#include <map>
#include <set>
#include <cstdio>
#include <stack>
#include <string>

using namespace std;

const int MAXN = 200005;

vector<int> t_start[MAXN * 4], t_end[MAXN * 4];

vector<pair<int, int> > ropes;

map<int, vector<int> > started, ended;

void init_start(int v, int tl, int tr) {
	if (tl == tr) {
		t_start[v] = started[tl];
	}
	else {
		int tmid = (tl + tr) / 2;
		init_start(2 * v + 1, tl, tmid);
		init_start(2 * v + 2, tmid + 1, tr);
	}
}

void init_end(int v, int tl, int tr) {
	if (tl == tr) {
		t_end[v] = ended[tl];
	}
	else {
		int tmid = (tl + tr) / 2;
		init_end(2 * v + 1, tl, tmid);
		init_end(2 * v + 2, tmid + 1, tr);
	}
}

vector<int> query_start(int left, int right, int v, int tl, int tr) {
	if (left > right) {
		return vector<int>();
	}
	if (tl == left && tr == right) {
		return t_start[v];
	}
	else {
		const int tmid = (tl + tr) / 2;
		if (right <= tmid) {
			return query_start(left, right, 2 * v + 1, tl, tmid);
		}
		if (left > tmid) {
			return query_start(left, right, 2 * v + 2, tmid + 1, tr);
		}
		
		vector<int> a = query_start(left, tmid, 2 * v + 1, tl, tmid);
		vector<int> b = query_start(tmid + 1, right, 2 * v + 2, tmid + 1, tr);

		vector<int> ret(a.size() + b.size());
		const int new_size = set_union(a.begin(), a.end(), b.begin(), b.end(), ret.begin()) - ret.begin();
		ret.resize(new_size);
		return ret;
	}
}

vector<int> query_end(int left, int right, int v, int tl, int tr) {
	if (left > right) {
		return vector<int>();
	}
	if (tl == left && tr == right) {
		return t_end[v];
	}
	else {
		const int tmid = (tl + tr) / 2;
		if (right <= tmid) {
			return query_end(left, right, 2 * v + 1, tl, tmid);
		}
		if (left > tmid) {
			return query_end(left, right, 2 * v + 2, tmid + 1, tr);
		}

		vector<int> a = query_end(left, tmid, 2 * v + 1, tl, tmid);
		vector<int> b = query_end(tmid + 1, right, 2 * v + 2, tmid + 1, tr);

		vector<int> ret(a.size() + b.size());
		const int new_size = set_union(a.begin(), a.end(), b.begin(), b.end(), ret.begin()) - ret.begin();
		ret.resize(new_size);
		return ret;
	}
}

int main() {
#ifndef _DEBUG
	freopen("improvements.in", "r", stdin);
	freopen("improvements.out", "w", stdout);
#endif

	ios_base::sync_with_stdio(false);
	
	int n; cin >> n;
	vector<int> points(n);
	for (int i = 0; i < n; ++i) {
		cin >> points[i];
	}

	ropes.resize(n - 1);
	for (int i = 1; i < n; ++i) {
		ropes[i - 1] = make_pair(points[i - 1], points[i]);
	}

	for (int i = 0; i < n - 1; ++i) {
		int a = std::min(ropes[i].first, ropes[i].second);
		int b = std::max(ropes[i].first, ropes[i].second);
		started[a].push_back(i);
		ended[b].push_back(i);
	}

	init_start(0, 0, n);
	init_end(0, 0, n);

	set<int> set_ropes;
	for (int i = 0; i < n - 1; ++i) {
		const int a = ropes[i].first, b = ropes[i].second;

		vector<int> left1 = query_start(0, a - 1, 0, 0, n);
		vector<int> left2 = query_end(a + 1, b - 1, 0, 0, n);

		vector<int> fleft(std::min(left1.size(), left2.size()));
		int new_size = set_intersection(left1.begin(), left1.end(), left2.begin(), left2.end(), fleft.begin()) - fleft.begin();
		fleft.resize(new_size);

		vector<int> right1 = query_start(a + 1, b - 1, 0, 0, n);
		vector<int> right2 = query_end(b + 1, n, 0, 0, n);

		vector<int> fright(std::min(right1.size(), right2.size()));
		new_size = set_intersection(right1.begin(), right1.end(), right2.begin(), right2.end(), fright.begin()) - fright.begin();
		fright.resize(new_size);

		for (int j = 0; j < fleft.size(); ++j) {
			set_ropes.insert(fleft[j]);
		}
		for (int j = 0; j < fright.size(); ++j) {
			set_ropes.insert(fright[j]);
		}

		if (!fleft.empty() || !fright.empty()) {
			set_ropes.insert(i);
		}
	}
	
	vector<int> ropes_ends;
	for (auto it = set_ropes.begin(); it != set_ropes.end(); ++it) {
		ropes_ends.push_back(ropes[*it].first);
		ropes_ends.push_back(ropes[*it].second);
	}

	if (ropes_ends.empty()) {
		cout << n << endl;
		return 0;
	}
	sort(ropes_ends.begin(), ropes_ends.end());

	int ret = 0;
	for (int i = 0; i < ropes_ends.size() - 1; ++i) {
		if (ropes_ends[i] == ropes_ends[i + 1]) {
			++ret;
		}
	}

	const int finalret = ret + (set_ropes.size() - 2 * ret) / 2;
	cout << n - finalret << endl;

}
