import java.io.InputStreamReader;
import java.io.IOException;
import java.io.BufferedReader;
import java.io.OutputStream;
import java.io.FileOutputStream;
import java.io.PrintWriter;
import java.io.FileInputStream;
import java.util.StringTokenizer;
import java.io.InputStream;

/**
 * Built using CHelper plug-in
 * Actual solution is at the top
 */
public class Main {
	public static void main(String[] args) {
		InputStream inputStream;
		try {
			inputStream = new FileInputStream("damage.in");
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		OutputStream outputStream;
		try {
			outputStream = new FileOutputStream("damage.out");
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		InputReader in = new InputReader(inputStream);
		PrintWriter out = new PrintWriter(outputStream);
		Damage solver = new Damage();
		solver.solve(1, in, out);
		out.close();
	}
}

class Damage {
    static final int POINTS = (int) 1e6;

    public void solve(int testNumber, InputReader in, PrintWriter out) {
        int d = in.nextInt();
        int l = in.nextInt();
        int r = in.nextInt();
        int t = in.nextInt();
        int h = in.nextInt();
        double vx = Math.sqrt(l * l - t * t) / l;
        double vy = (double) t / l;
        double res = bottomSphere(d, r, h, vx, vy) + cylinder(d, l, h, vx, vy) + topSphere(d, r, h, l, vx, vy);
        out.println(res / 1e6);
    }

    private double topSphere(int d, int r, int h, int l, double vx, double vy) {
        double rDist = Math.sqrt(r * (double) r - d * (double) d / 4.0);
        double num = 0;
        double den = 0;
        for (int i = 0; i <= POINTS; ++i) {
            double dist = (i * (double) r + (POINTS - i) * rDist) / POINTS;
            double rad = Math.sqrt(r * r - dist * dist);
            double ymin = (l + dist - rDist) * vy - rad * vx + d / 2.0 * vx;
            double ymax = (l + dist - rDist) * vy + rad * vx + d / 2.0 * vx;
            double area;
            if (ymin > h) area = circleFrac(0.0); else if (ymax <= h) area = circleFrac(1.0); else {
                double frac = (h - ymin) / (ymax - ymin);
                area = circleFrac(frac);
            }
            area *= rad * rad;
            int mult = (i == 0 || i == POINTS) ? 1 : ((i % 2 == 0) ? 2 : 4);
            den += mult;
            num += mult * area;
        }
        return (r - rDist) * num / den;
    }

    private double cylinder(int d, int l, int h, double vx, double vy) {
        double num = 0;
        double den = 0;
        for (int i = 0; i <= POINTS; ++i) {
            double offset = i * (double) l / POINTS;
            double rad = d / 2.0;
            double ymin = offset * vy;
            double ymax = offset * vy + d * vx;
            double area;
            if (ymin > h) area = circleFrac(0.0); else if (ymax <= h) area = circleFrac(1.0); else {
                double frac = (h - ymin) / (ymax - ymin);
                area = circleFrac(frac);
            }
            area *= rad * rad;
            int mult = (i == 0 || i == POINTS) ? 1 : ((i % 2 == 0) ? 2 : 4);
            den += mult;
            num += mult * area;
        }
        return l * num / den;
    }

    private double bottomSphere(int d, int r, int h, double vx, double vy) {
        double rDist = Math.sqrt(r * (double) r - d * (double) d / 4.0);
        double num = 0;
        double den = 0;
        for (int i = 0; i <= POINTS; ++i) {
            double dist = (i * (double) r + (POINTS - i) * rDist) / POINTS;
            double rad = Math.sqrt(r * r - dist * dist);
            double ymin = -(dist - rDist) * vy - rad * vx + d / 2.0 * vx;
            double ymax = -(dist - rDist) * vy + rad * vx + d / 2.0 * vx;
            double area;
            if (ymin > h) area = circleFrac(0.0); else if (ymax <= h) area = circleFrac(1.0); else {
                double frac = (h - ymin) / (ymax - ymin);
                area = circleFrac(frac);
            }
            area *= rad * rad;
            int mult = (i == 0 || i == POINTS) ? 1 : ((i % 2 == 0) ? 2 : 4);
            den += mult;
            num += mult * area;
        }
        return (r - rDist) * num / den;
    }

    private double circleFrac(double frac) {
        if (frac >= 1.0) return Math.PI;
        if (frac <= 0.0) return 0.0;
        if (frac > 0.5) return Math.PI - circleFrac(1.0 - frac);
        double outside = 2 * (0.5 - frac);
        double alpha = Math.acos(outside);
        return alpha - Math.sin(2 * alpha) / 2.0;
    }
}

class InputReader {
    public BufferedReader reader;
    public StringTokenizer tokenizer;

    public InputReader(InputStream stream) {
        reader = new BufferedReader(new InputStreamReader(stream), 32768);
        tokenizer = null;
    }

    public String next() {
        while (tokenizer == null || !tokenizer.hasMoreTokens()) {
            try {
                tokenizer = new StringTokenizer(reader.readLine());
            } catch (IOException e) {
                throw new RuntimeException(e);
            }
        }
        return tokenizer.nextToken();
    }

    public int nextInt() {
        return Integer.parseInt(next());
    }

}

